.. harissa documentation master file, created by
   sphinx-quickstart on Wed Oct 25 10:13:37 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Harissa's 🌶 documentation!
######################################

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   Harissa <README>
   modules
   notebooks/README

-------------------------------

.. include:: ../../README.rst
    :start-line: 3
    :end-line: 7

.. include:: ../../README.rst
   :start-line: 11
   :end-line: 111

Indices and tables
##################

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
